/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the mozCellML code.
 *
 * The Initial Developer of the Original Code is
 * The Bioengineering Institute, University of Auckland.
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Andrew Miller <ak.miller@auckland.ac.nz> (original developer)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "mozCellMLLoadError.h"
#include <nsIStringBundle.h>
#include <nspr.h>

NS_IMPL_ISUPPORTS1(mozCellMLLoadError, mozCellMLILoadError)
 
mozCellMLLoadError::mozCellMLLoadError(const nsAString& imsg)
  : numargs(0), msg(imsg)
{
}

mozCellMLLoadError::mozCellMLLoadError(const nsAString& imsg,
                                       const nsACString& iarg1)
  : numargs(1), msg(imsg), arg1(iarg1)
{
}

mozCellMLLoadError::mozCellMLLoadError(const nsAString& imsg,
                                       const nsACString& iarg1,
                                       const nsACString& iarg2)
  : numargs(2), msg(imsg), arg1(iarg1), arg2(iarg2)
{
}
 
mozCellMLLoadError::~mozCellMLLoadError()
{
}
                                                                                                                                                            
NS_IMETHODIMP
mozCellMLLoadError::GetError(nsIStringBundle* bundle, nsAString& aErrorMessage)
{
  nsCAutoString ctrans;
  if (bundle == nsnull)
  {
    nsCAutoString msgCode;
    CopyUTF16toUTF8(msg, msgCode);
    ctrans = NS_LITERAL_CSTRING("Error message unavailable(no bundle). Message Code ") + msgCode;
  }
  else
  {
    nsXPIDLString wtrans;
    nsresult rv = bundle->GetStringFromName(msg.get(), getter_Copies(wtrans));
    if (rv != NS_OK)
    {
      nsCAutoString msgCode;
      CopyUTF16toUTF8(msg, msgCode);
      ctrans = NS_LITERAL_CSTRING("Error message unavailable(not in translation). Message Code ") + msgCode;
    }
    else
      CopyUTF16toUTF8(wtrans, ctrans);
  }
  char* result;
  nsCString cresult;
  switch (numargs)
  {
  case 0:
    cresult = ctrans;
    break;
  case 1:
    result = PR_smprintf(ctrans.get(), arg1.get());
    cresult = result;
    PR_Free(result);
    break;
  default:
    result = PR_smprintf(ctrans.get(), arg1.get(), arg2.get());
    cresult = result;
    PR_Free(result);
  }
  CopyUTF8toUTF16(cresult, aErrorMessage);
  return NS_OK;
}
